@@ -309,7 +309,6 @@ var menudata={children:[
 {text:"x",url:"functions_eval_x.html#index_x"},
 {text:"y",url:"functions_eval_y.html#index_y"},
 {text:"z",url:"functions_eval_z.html#index_z"}]},
-{text:"Properties",url:"functions_prop.html"},
 {text:"Related Symbols",url:"functions_rela.html",children:[
 {text:":",url:"functions_rela.html#index_:"},
 {text:"a",url:"functions_rela_a.html#index_a"},
@@ -438,6 +437,7 @@ var menudata={children:[
 {text:"i",url:"globals_enum.html#index_i"},
 {text:"p",url:"globals_enum.html#index_p"},
 {text:"r",url:"globals_enum.html#index_r"},
+{text:"t",url:"globals_enum.html#index_t"},
 {text:"v",url:"globals_enum.html#index_v"},
 {text:"w",url:"globals_enum.html#index_w"},
 {text:"z",url:"globals_enum.html#index_z"}]},
@@ -478,4 +478,5 @@ var menudata={children:[
 {text:"w",url:"globals_defs_w.html#index_w"},
 {text:"x",url:"globals_defs_x.html#index_x"},
 {text:"y",url:"globals_defs_y.html#index_y"},
-{text:"z",url:"globals_defs_z.html#index_z"}]}]}]}]}
+{text:"z",url:"globals_defs_z.html#index_z"}]}]}]},
+{text:"Examples",url:"examples.html"}]}
